@@ -30,7 +30,7 @@
  * Return the current expiration time desired by the
  * user (in the 'edit secret' dialog).
  */
-struct GNUNET_TIME_Absolute
+struct GNUNET_TIME_Timestamp
 AG_get_desired_expiration (void);
 
 #endif
